@@ -847,6 +847,7 @@ bfs_tests=(
     test_printf_duplicate_flag
     test_printf_must_be_numeric
     test_printf_color
+    test_printf_everything
 
     test_type_multi
 
@@ -858,6 +859,9 @@ bfs_tests=(
 
     test_version
 
+    test_warn
+    test_nowarn
+
     test_xtype_multi
 
     # Optimizer tests
@@ -2487,6 +2491,18 @@ function test_printf_color() {
     bfs_diff -color -path './rainbow*' -printf '%H %h %f %p %P %l\n'
 }
 
+function test_printf_everything() {
+    local everything=(%{a,b,c,d,D,f,F,g,G,h,H,i,k,l,m,M,n,p,P,s,S,t,u,U,y,Y})
+    everything+=(%{A,C,T}{%,+,@,a,A,b,B,c,C,d,D,e,F,g,G,h,H,I,j,k,l,m,M,n,p,r,R,s,S,t,T,u,U,V,w,W,x,X,y,Y,z,Z})
+
+    # Check if we have birth times
+    if ! fail invoke_bfs basic -printf '%w' -quit >/dev/null; then
+        everything+=(%w %{B,W}{%,+,@,a,A,b,B,c,C,d,D,e,F,g,G,h,H,I,j,k,l,m,M,n,p,r,R,s,S,t,T,u,U,V,w,W,x,X,y,Y,z,Z})
+    fi
+
+    invoke_bfs rainbow -printf "${everything[*]}\n" >/dev/null
+}
+
 function test_fprintf() {
     invoke_bfs basic -fprintf scratch/test_fprintf.out '%%p(%p) %%d(%d) %%f(%f) %%h(%h) %%H(%H) %%P(%P) %%m(%m) %%M(%M) %%y(%y)\n'
     sort -o scratch/test_fprintf.out scratch/test_fprintf.out
@@ -3245,6 +3261,16 @@ function test_version() {
     invoke_bfs -version >/dev/null
 }
 
+function test_warn() {
+    local stderr=$(invoke_bfs basic -warn -depth -prune 2>&1 >/dev/null)
+    [ -n "$stderr" ]
+}
+
+function test_nowarn() {
+    local stderr=$(invoke_bfs basic -nowarn -depth -prune 2>&1 >/dev/null)
+    [ -z "$stderr" ]
+}
+
 function test_typo() {
     invoke_bfs -dikkiq 2>&1 | grep follow >/dev/null
 }
